@@ -11,8 +11,11 @@ from .constants import BESSEL_LOWPASS_10_UUID
 from .constants import BESSEL_LOWPASS_30_UUID
 from .constants import BUTTERWORTH_LOWPASS_30_UUID
 from .constants import CENTIMILLISECONDS_PER_SECOND
+from .constants import CONTRACTION_TIME_UUID
 from .constants import CONTRACTION_VELOCITY_UUID
+from .constants import FRACTION_MAX_UUID
 from .constants import IRREGULARITY_INTERVAL_UUID
+from .constants import MICRO_TO_BASE_CONVERSION
 from .constants import MIDSCALE_CODE
 from .constants import MILLI_TO_BASE_CONVERSION
 from .constants import MILLIMETERS_PER_MILLITESLA
@@ -24,9 +27,11 @@ from .constants import PRIOR_PEAK_INDEX_UUID
 from .constants import PRIOR_VALLEY_INDEX_UUID
 from .constants import RAW_TO_SIGNED_CONVERSION_VALUE
 from .constants import REFERENCE_VOLTAGE
+from .constants import RELAXATION_TIME_UUID
 from .constants import RELAXATION_VELOCITY_UUID
 from .constants import SUBSEQUENT_PEAK_INDEX_UUID
 from .constants import SUBSEQUENT_VALLEY_INDEX_UUID
+from .constants import TIME_DIFFERENCE_UUID
 from .constants import TWITCH_FREQUENCY_UUID
 from .constants import TWITCH_PERIOD_UUID
 from .constants import WIDTH_FALLING_COORDS_UUID
@@ -35,6 +40,7 @@ from .constants import WIDTH_UUID
 from .constants import WIDTH_VALUE_UUID
 from .exceptions import DataAlreadyLoadedInPipelineError
 from .exceptions import FilterCreationNotImplementedError
+from .exceptions import PeakDetectionError
 from .exceptions import TooFewPeaksDetectedError
 from .exceptions import TwoPeaksInARowError
 from .exceptions import TwoValleysInARowError
@@ -53,10 +59,12 @@ from .transforms import create_filter
 from .transforms import FILTER_CHARACTERISTICS
 from .transforms import noise_cancellation
 
+# Kristian 9/15/21
+
 
 if 5 < 10:  # pragma: no cover # protect this from zimports deleting the pylint disable statement
     from .compression_cy import (  # pylint: disable=import-error # Eli (8/18/20) unsure why pylint is unable to recognize cython import... # Tanner (8/31/20) Pylint also flags this as duplicate code due to a similar import in pipelines.py, which may be related to pylint's import issues
-        compress_filtered_gmr,
+        compress_filtered_magnetic_data,
     )
 
 __all__ = [
@@ -90,7 +98,7 @@ __all__ = [
     "BESSEL_BANDPASS_UUID",
     "BESSEL_LOWPASS_10_UUID",
     "FILTER_CHARACTERISTICS",
-    "compress_filtered_gmr",
+    "compress_filtered_magnetic_data",
     "calculate_voltage_from_gmr",
     "calculate_displacement_from_voltage",
     "PipelineTemplate",
@@ -113,4 +121,10 @@ __all__ = [
     "ADC_GAIN",
     "IRREGULARITY_INTERVAL_UUID",
     "ALL_METRICS",
+    "FRACTION_MAX_UUID",
+    "TIME_DIFFERENCE_UUID",
+    "RELAXATION_TIME_UUID",
+    "CONTRACTION_TIME_UUID",
+    "MICRO_TO_BASE_CONVERSION",
+    "PeakDetectionError",
 ]
