@@ -19,16 +19,20 @@ from scipy import signal
 from .constants import ALL_METRICS
 from .constants import AMPLITUDE_UUID
 from .constants import AUC_UUID
-from .constants import CENTIMILLISECONDS_PER_SECOND
+from .constants import CONTRACTION_TIME_UUID
 from .constants import CONTRACTION_VELOCITY_UUID
+from .constants import FRACTION_MAX_UUID
 from .constants import IRREGULARITY_INTERVAL_UUID
+from .constants import MICRO_TO_BASE_CONVERSION
 from .constants import MIN_NUMBER_PEAKS
 from .constants import MIN_NUMBER_VALLEYS
 from .constants import PRIOR_PEAK_INDEX_UUID
 from .constants import PRIOR_VALLEY_INDEX_UUID
+from .constants import RELAXATION_TIME_UUID
 from .constants import RELAXATION_VELOCITY_UUID
 from .constants import SUBSEQUENT_PEAK_INDEX_UUID
 from .constants import SUBSEQUENT_VALLEY_INDEX_UUID
+from .constants import TIME_DIFFERENCE_UUID
 from .constants import TWITCH_FREQUENCY_UUID
 from .constants import TWITCH_PERIOD_UUID
 from .constants import WIDTH_FALLING_COORDS_UUID
@@ -48,33 +52,37 @@ TWITCH_WIDTH_INDEX_OF_CONTRACTION_VELOCITY_END = TWITCH_WIDTH_PERCENTS.index(90)
 def peak_detector(
     filtered_magnetic_signal: NDArray[(2, Any), int],
     twitches_point_up: bool = True,
+    is_magnetic_data: bool = True,
 ) -> Tuple[List[int], List[int]]:
     """Locates peaks and valleys and returns the indices.
 
     Args:
-        noise_free_data: a 2D array of the time and voltage data after it has gone through noise cancellation
-        sampling_rate: an integer value of the sampling rate of the data in Hz
+        filtered_magnetic_signal: a 2D array of the magnetic signal vs time data after it has gone through noise cancellation. It is assumed that the time values are in microseconds
         twitches_point_up: whether in the incoming data stream the biological twitches are pointing up (in the positive direction) or down
-        data: a 2D array of the original time and voltage before noise cancellation
+        is_magnetic_data: whether the incoming data stream is magnetic data or not
+        sampling_period: Optional value indicating the period that magnetic data was sampled at. If not given, the sampling period will be calculated using the difference of the first two time indices
 
     Returns:
-        A tuple of the indices of the peaks and valleys
+        A tuple containing a list of the indices of the peaks and a list of the indices of valleys
     """
     magnetic_signal: NDArray[int] = filtered_magnetic_signal[1, :]
-    magnetic_signal *= -1
+    if is_magnetic_data:
+        magnetic_signal *= -1
 
     peak_invertor_factor = 1
     valley_invertor_factor = -1
     if not twitches_point_up:
         peak_invertor_factor *= -1
         valley_invertor_factor *= -1
-    sampling_period_cms = filtered_magnetic_signal[0, 1] - filtered_magnetic_signal[0, 0]
-    maximum_possible_twitch_frequency = 7  # pylint:disable=invalid-name # (Eli 9/1/20): I can't think of a shorter name to describe this concept fully # Hz
-    minimum_required_samples_between_twitches = int(  # pylint:disable=invalid-name # (Eli 9/1/20): I can't think of a shorter name to describe this concept fully
+
+    sampling_period_us = filtered_magnetic_signal[0, 1] - filtered_magnetic_signal[0, 0]
+
+    max_possible_twitch_freq = 7
+    min_required_samples_between_twitches = int(  # pylint:disable=invalid-name # (Eli 9/1/20): I can't think of a shorter name to describe this concept fully
         round(
-            (1 / maximum_possible_twitch_frequency) * CENTIMILLISECONDS_PER_SECOND / sampling_period_cms,
+            (1 / max_possible_twitch_freq) * MICRO_TO_BASE_CONVERSION / sampling_period_us,
             0,
-        )
+        ),
     )
 
     # find required height of peaks
@@ -84,26 +92,26 @@ def peak_detector(
     # find peaks and valleys
     peak_indices, _ = signal.find_peaks(
         magnetic_signal * peak_invertor_factor,
-        width=minimum_required_samples_between_twitches / 2,
-        distance=minimum_required_samples_between_twitches,
+        width=min_required_samples_between_twitches / 2,
+        distance=min_required_samples_between_twitches,
         prominence=max_prominence / 4,
     )
     valley_indices, properties = signal.find_peaks(
         magnetic_signal * valley_invertor_factor,
-        width=minimum_required_samples_between_twitches / 2,
-        distance=minimum_required_samples_between_twitches,
+        width=min_required_samples_between_twitches / 2,
+        distance=min_required_samples_between_twitches,
         prominence=max_prominence / 4,
     )
     left_ips = properties["left_ips"]
     right_ips = properties["right_ips"]
 
-    # TODO Tanner (11/3/20): move this loop to find_twitch_indices
     # Patches error in B6 file for when two valleys are found in a single valley. If this is true left_bases, right_bases, prominences, and raw magnetic sensor data will also be equivalent to their previous value. This if statement indicates that the valley should be disregarded if the interpolated values on left and right intersection points of a horizontal line at the an evaluation height are equivalent. This would mean that the left and right sides of the peak and its neighbor peak align, indicating that it just one peak rather than two.
     # https://docs.scipy.org/doc/scipy/reference/generated/scipy.signal.peak_widths.html#scipy.signal.peak_widths
 
+    # Tanner (10/28/21): be careful modifying any of this while loop, it is currently not unit tested
     i = 1
     while i < len(valley_indices):
-        if left_ips[i] == left_ips[i - 1] and right_ips[i] == right_ips[i - 1]:
+        if left_ips[i] == left_ips[i - 1] and right_ips[i] == right_ips[i - 1]:  # pragma: no cover
             valley_idx = valley_indices[i]
             valley_idx_last = valley_indices[i - 1]
 
@@ -112,17 +120,17 @@ def peak_detector(
                 left_ips = np.delete(left_ips, i)
                 right_ips = np.delete(right_ips, i)
             else:  # pragma: no cover # (Anna 3/31/21): we don't have a case as of yet in which the first peak is higher than the second however know that it is possible and therefore aren't worried about code coverage in this case.
-                valley_indices = np.delete(valley_indices, i - 1)  # pragma: no cover
-                left_ips = np.delete(left_ips, i - 1)  # pragma: no cover
-                right_ips = np.delete(right_ips, i - 1)  # pragma: no cover
+                valley_indices = np.delete(valley_indices, i - 1)
+                left_ips = np.delete(left_ips, i - 1)
+                right_ips = np.delete(right_ips, i - 1)
         else:
             i += 1
 
     return peak_indices, valley_indices
 
 
-def create_avg_dict(metric: NDArray[int], round_to_int: bool = True) -> Dict[str, Union[Float64, int]]:
-    """Calculate the average values of a specific metric.
+def create_statistics_dict(metric: NDArray[int], round_to_int: bool = True) -> Dict[str, Union[Float64, int]]:
+    """Calculate various statistics for a specific metric.
 
     Args:
         metric: a 1D array of integer values of a specific metric results
@@ -132,17 +140,14 @@ def create_avg_dict(metric: NDArray[int], round_to_int: bool = True) -> Dict[str
     """
     dictionary: Dict[str, Union[Float64, int]] = dict()
     dictionary["n"] = len(metric)
-    if len(metric) > 0:
-        dictionary["mean"] = np.mean(metric)
-        dictionary["std"] = np.std(metric)
-        dictionary["min"] = np.min(metric)
-        dictionary["max"] = np.max(metric)
-    else:
-        dictionary["mean"] = None
-        dictionary["std"] = None
-        dictionary["min"] = None
-        dictionary["max"] = None
+    if len(metric) == 0:
+        dictionary.update({key: None for key in ("mean", "std", "min", "max")})
+        return dictionary
 
+    dictionary["mean"] = np.mean(metric)
+    dictionary["std"] = np.std(metric)
+    dictionary["min"] = np.min(metric)
+    dictionary["max"] = np.max(metric)
     if round_to_int:
         for iter_key in ("mean", "std", "min", "max"):
             dictionary[iter_key] = int(round(dictionary[iter_key]))
@@ -154,44 +159,23 @@ def data_metrics(
     filtered_data: NDArray[(2, Any), int],
     rounded: bool = True,
     metrics_to_create: Iterable[UUID] = ALL_METRICS,
-) -> Tuple[
-    Dict[
-        int,
-        Dict[
-            UUID,  # pylint: disable=duplicate-code # Anna (1/7/21): long type definition causing failure
-            Union[
-                Dict[int, Dict[UUID, Union[Tuple[int, int], int]]],
-                Union[float, int],
-            ],
-        ],  # pylint: disable=duplicate-code # Anna (1/7/21): long type definition causing failure
-    ],
-    Dict[
-        UUID,
-        Union[Dict[str, Union[float, int]], Dict[int, Dict[str, Union[float, int]]]],
-    ],
-]:  # pylint:disable=too-many-locals # Eli (9/8/20): there are a lot of metrics to calculate that need local variables
+) -> Tuple[Dict[int, Dict[UUID, Any]], Dict[UUID, Any]]:
+    # pylint:disable=too-many-locals # Eli (9/8/20): there are a lot of metrics to calculate that need local variables
     """Find all data metrics for individual twitches and averages.
 
     Args:
         peak_and_valley_indices: a tuple of integer value arrays representing the time indices of peaks and valleys within the data
         filtered_data: a 2D array of the time and voltage data after it has gone through noise cancellation
+        rounded: whether to round estimates to the nearest int
+        metrics_to_create: list of desired metrics
 
     Returns:
-        per_twitch_dict: a dictionary of individual peak metrics in which the twitch timepoint is accompanied by a dictionary in which the UUIDs for each twitch metric are the key and with its accompanying value as the value. For the Twitch Width metric UUID, another dictionary is stored in which the key is the percentage of the way down and the value is another dictionary in which the UUIDs for the rising coord, falling coord or width value are stored with the value as an int for the width value or a tuple of ints for the x/y coordinates
+        main_twitch_dict: a dictionary of individual peak metrics in which the twitch timepoint is accompanied by a dictionary in which the UUIDs for each twitch metric are the key and with its accompanying value as the value. For the Twitch Width metric UUID, another dictionary is stored in which the key is the percentage of the way down and the value is another dictionary in which the UUIDs for the rising coord, falling coord or width value are stored with the value as an int for the width value or a tuple of ints for the x/y coordinates
         aggregate_dict: a dictionary of entire metric statistics. Most metrics have the stats underneath the UUID, but for twitch widths, there is an additional dictionary where the percent of repolarization is the key
     """
     # create main dictionaries
-    main_twitch_dict: Dict[
-        int,
-        Dict[
-            UUID,
-            Union[Dict[int, Dict[UUID, Union[Tuple[int, int], int]]], Union[float, int]],
-        ],
-    ] = dict()
-    aggregate_dict: Dict[
-        UUID,
-        Union[Dict[str, Union[float, int]], Dict[int, Dict[str, Union[float, int]]]],
-    ] = dict()
+    main_twitch_dict: Dict[int, Dict[UUID, Any]] = dict()
+    aggregate_dict: Dict[UUID, Any] = dict()
 
     # get values needed for metrics creation
     peak_indices, _ = peak_and_valley_indices
@@ -208,27 +192,39 @@ def data_metrics(
         combined_twitch_periods = calculate_twitch_period(twitch_indices, peak_indices, filtered_data)
     if TWITCH_PERIOD_UUID in metrics_to_create:
         _add_per_twitch_metrics(main_twitch_dict, TWITCH_PERIOD_UUID, combined_twitch_periods)
-        aggregate_dict[TWITCH_PERIOD_UUID] = create_avg_dict(combined_twitch_periods)
+        aggregate_dict[TWITCH_PERIOD_UUID] = create_statistics_dict(combined_twitch_periods)
 
     # find twitch frequencies
     if TWITCH_FREQUENCY_UUID in metrics_to_create:
-        twitch_frequencies = 1 / (combined_twitch_periods.astype(float) / CENTIMILLISECONDS_PER_SECOND)
+        twitch_frequencies = 1 / (combined_twitch_periods.astype(float) / MICRO_TO_BASE_CONVERSION)
         _add_per_twitch_metrics(main_twitch_dict, TWITCH_FREQUENCY_UUID, twitch_frequencies)
-        aggregate_dict[TWITCH_FREQUENCY_UUID] = create_avg_dict(twitch_frequencies, round_to_int=False)
+        aggregate_dict[TWITCH_FREQUENCY_UUID] = create_statistics_dict(twitch_frequencies, round_to_int=False)
 
     # find twitch amplitudes
     if AMPLITUDE_UUID in metrics_to_create:
         amplitudes: NDArray[int] = calculate_amplitudes(twitch_indices, filtered_data, round_to_int=rounded)
         _add_per_twitch_metrics(main_twitch_dict, AMPLITUDE_UUID, amplitudes)
-        aggregate_dict[AMPLITUDE_UUID] = create_avg_dict(amplitudes, round_to_int=rounded)
+        aggregate_dict[AMPLITUDE_UUID] = create_statistics_dict(amplitudes, round_to_int=rounded)
+
+    # find fraction of max amplitude
+    # dependent on computing amplitudes
+    if FRACTION_MAX_UUID in metrics_to_create and AMPLITUDE_UUID in metrics_to_create:
+
+        amplitude_fraction_of_max: NDArray[float] = amplitudes / aggregate_dict[AMPLITUDE_UUID]["max"]
+        _add_per_twitch_metrics(main_twitch_dict, FRACTION_MAX_UUID, amplitude_fraction_of_max)
+        aggregate_dict[FRACTION_MAX_UUID] = create_statistics_dict(
+            amplitude_fraction_of_max, round_to_int=False
+        )
 
     # find twitch widths
     if (
         WIDTH_UUID in metrics_to_create
         or CONTRACTION_VELOCITY_UUID in metrics_to_create
         or RELAXATION_VELOCITY_UUID in metrics_to_create
+        or TIME_DIFFERENCE_UUID in metrics_to_create
     ):
         widths = calculate_twitch_widths(twitch_indices, filtered_data, round_to_int=rounded)
+
     if WIDTH_UUID in metrics_to_create:
         _add_per_twitch_metrics(main_twitch_dict, WIDTH_UUID, widths)
 
@@ -242,25 +238,47 @@ def data_metrics(
                         f"The width value under key {WIDTH_VALUE_UUID} must be a float or an int. It was: {iter_width_value}"
                     )
                 iter_list_of_width_values.append(iter_width_value)
-            iter_stats_dict = create_avg_dict(iter_list_of_width_values, round_to_int=rounded)
+            iter_stats_dict = create_statistics_dict(iter_list_of_width_values, round_to_int=rounded)
             width_stats_dict[iter_percent] = iter_stats_dict
         aggregate_dict[WIDTH_UUID] = width_stats_dict
 
+    # compute time-difference of each twitch-width to peak
+    if TIME_DIFFERENCE_UUID in metrics_to_create:
+        difference_times = calculate_twitch_time_diff(twitch_indices, filtered_data, widths)
+        _add_per_twitch_metrics(main_twitch_dict, TIME_DIFFERENCE_UUID, difference_times)
+        for time_to_peak_uuid in [RELAXATION_TIME_UUID, CONTRACTION_TIME_UUID]:
+            difference_stats_dict: Dict[int, Dict[str, Union[float, int]]] = dict()
+            for iter_percent in TWITCH_WIDTH_PERCENTS:
+                iter_list_difference_times: List[Union[float, int]] = []
+                for iter_difference in difference_times:
+                    iter_difference_value = iter_difference[iter_percent][time_to_peak_uuid]
+                    iter_list_difference_times.append(iter_difference_value)
+                    iter_relaxation_stats_dict = create_statistics_dict(iter_list_difference_times)
+                difference_stats_dict[iter_percent] = iter_relaxation_stats_dict
+            aggregate_dict[time_to_peak_uuid] = difference_stats_dict
+
     # calculate twitch contraction/relaxation velocities
     if CONTRACTION_VELOCITY_UUID in metrics_to_create:
         contraction_velocity = calculate_twitch_velocity(twitch_indices, widths, True)
         _add_per_twitch_metrics(main_twitch_dict, CONTRACTION_VELOCITY_UUID, contraction_velocity)
-        aggregate_dict[CONTRACTION_VELOCITY_UUID] = create_avg_dict(contraction_velocity, round_to_int=False)
+        aggregate_dict[CONTRACTION_VELOCITY_UUID] = create_statistics_dict(
+            contraction_velocity, round_to_int=False
+        )
+
     if RELAXATION_VELOCITY_UUID in metrics_to_create:
         relaxation_velocity = calculate_twitch_velocity(twitch_indices, widths, False)
         _add_per_twitch_metrics(main_twitch_dict, RELAXATION_VELOCITY_UUID, relaxation_velocity)
-        aggregate_dict[RELAXATION_VELOCITY_UUID] = create_avg_dict(relaxation_velocity, round_to_int=False)
+        aggregate_dict[RELAXATION_VELOCITY_UUID] = create_statistics_dict(
+            relaxation_velocity, round_to_int=False
+        )
 
     # calculate twitch interval irregularity
     if IRREGULARITY_INTERVAL_UUID in metrics_to_create:
         interval_irregularity = calculate_interval_irregularity(twitch_indices, time_series)
         _add_per_twitch_metrics(main_twitch_dict, IRREGULARITY_INTERVAL_UUID, interval_irregularity)
-        interval_irregularity_averages = create_avg_dict(interval_irregularity[1:-1], round_to_int=False)
+        interval_irregularity_averages = create_statistics_dict(
+            interval_irregularity[1:-1], round_to_int=False
+        )
         interval_irregularity_averages["n"] += 2
         aggregate_dict[IRREGULARITY_INTERVAL_UUID] = interval_irregularity_averages
 
@@ -270,7 +288,7 @@ def data_metrics(
             twitch_indices, filtered_data, widths, round_to_int=rounded
         )
         _add_per_twitch_metrics(main_twitch_dict, AUC_UUID, auc_per_twitch)
-        aggregate_dict[AUC_UUID] = create_avg_dict(auc_per_twitch, round_to_int=rounded)
+        aggregate_dict[AUC_UUID] = create_statistics_dict(auc_per_twitch, round_to_int=rounded)
 
     return main_twitch_dict, aggregate_dict
 
@@ -423,15 +441,11 @@ def find_twitch_indices(
     while peak_idx < len(peak_indices) and valley_idx < len(valley_indices):
         if prev_feature_is_peak:
             if valley_indices[valley_idx] > peak_indices[peak_idx]:
-                raise TwoPeaksInARowError(
-                    (peak_indices[peak_idx - 1], peak_indices[peak_idx]),
-                )
+                raise TwoPeaksInARowError((peak_indices[peak_idx - 1], peak_indices[peak_idx]))
             valley_idx += 1
         else:
             if valley_indices[valley_idx] < peak_indices[peak_idx]:
-                raise TwoValleysInARowError(
-                    (valley_indices[valley_idx - 1], valley_indices[valley_idx]),
-                )
+                raise TwoValleysInARowError((valley_indices[valley_idx - 1], valley_indices[valley_idx]))
             peak_idx += 1
         prev_feature_is_peak = not prev_feature_is_peak
     if peak_idx < len(peak_indices) - 1:
@@ -439,16 +453,13 @@ def find_twitch_indices(
             (peak_indices[peak_idx], peak_indices[peak_idx + 1]),
         )
     if valley_idx < len(valley_indices) - 1:
-        raise TwoValleysInARowError(
-            (valley_indices[valley_idx], valley_indices[valley_idx + 1]),
-        )
+        raise TwoValleysInARowError((valley_indices[valley_idx], valley_indices[valley_idx + 1]))
 
     # compile dict of twitch information
     for itr_idx, itr_peak_index in enumerate(peak_indices):
         if itr_idx < peak_indices.shape[0] - 1:  # last peak
             if itr_idx == 0 and starts_with_peak:
                 continue
-
             twitches[itr_peak_index] = {
                 PRIOR_PEAK_INDEX_UUID: None if itr_idx == 0 else peak_indices[itr_idx - 1],
                 PRIOR_VALLEY_INDEX_UUID: valley_indices[itr_idx - 1 if starts_with_peak else itr_idx],
@@ -517,7 +528,9 @@ def calculate_amplitudes(
         prior_amplitude = amplitude_series[iter_twitch_indices_info[PRIOR_VALLEY_INDEX_UUID]]
         subsequent_amplitude = amplitude_series[iter_twitch_indices_info[SUBSEQUENT_VALLEY_INDEX_UUID]]
         amplitude_value = ((peak_amplitude - prior_amplitude) + (peak_amplitude - subsequent_amplitude)) / 2
-        if round_to_int:
+        if (
+            round_to_int
+        ):  # pragma: no cover  # Tanner (10/28/21): currently no tests that cover this branch but it could be still called in Pulse3D
             amplitude_value = int(round(amplitude_value, 0))
 
         amplitudes.append(abs(amplitude_value))
@@ -555,11 +568,71 @@ def interpolate_y_for_x_between_two_points(  # pylint:disable=invalid-name # (El
     return slope * (desired_x - x_1) + y_1
 
 
+def calculate_twitch_time_diff(
+    twitch_indices: Dict[int, Dict[UUID, Optional[int]]],
+    filtered_data: NDArray[(2, Any), int],
+    per_twitch_widths: List[
+        Dict[
+            int,
+            Dict[
+                UUID,
+                Any,
+            ],
+        ],
+    ],
+) -> List[Dict[int, Dict[UUID, NDArray[float]]]]:
+    """Calculate time from percent contraction / relaxation to twitch peak.
+
+    Args:
+        twitch_indices: a dictionary in which the key is an integer representing the time points of all the peaks of interest and the value is an inner dictionary with various UUIDs of prior/subsequent peaks and valleys and their index values.
+        filtered_data: a 2D array of the time and value (magnetic, voltage, displacement, force...) data after it has gone through noise filtering
+        per_twitch_widths: a list of dictionaries where the first key is the percentage of the way down to the nearby valleys, the second key is a UUID representing either the value of the width, or the rising or falling coordinates. The final value is either an int representing the width value or a tuple of ints for the x/y coordinates
+    Returns:
+        time_differences: a list of dictionaries where the first key is the percentage of the way down to the nearby valleys, the second key is a UUID representing either the relaxation or contraction time.  The final value is float indicating time from relaxation/contraction to peak
+    """
+    # dictionary of time differences for each peak
+    time_differences: List[Dict[int, Dict[UUID, NDArray[float]]]] = list()
+
+    time_series = filtered_data[0, :]
+
+    for iter_twitch_idx, iter_twitch_peak_idx in enumerate(twitch_indices.keys()):
+
+        # get twitch value and time
+        time_value = time_series[iter_twitch_peak_idx]
+
+        # compile time differences for each peak
+        iter_twich_difference_dict: Dict[int, Dict[UUID, NDArray[float]]] = dict()
+
+        for iter_percent in TWITCH_WIDTH_PERCENTS:
+
+            iter_percent_coord_dict = per_twitch_widths[iter_twitch_idx][iter_percent]
+            iter_percent_difference_dict: Dict[UUID, NDArray[float]] = dict()
+
+            # compute time difference for single twitch width
+            for time_diff_uuid in [RELAXATION_TIME_UUID, CONTRACTION_TIME_UUID]:
+
+                is_contraction = time_diff_uuid == CONTRACTION_TIME_UUID
+                if is_contraction:
+                    rising_time = iter_percent_coord_dict[WIDTH_RISING_COORDS_UUID][0]
+                    difference = time_value - rising_time
+                else:
+                    falling_time = iter_percent_coord_dict[WIDTH_FALLING_COORDS_UUID][0]
+                    difference = falling_time - time_value
+
+                iter_percent_difference_dict[time_diff_uuid] = difference
+
+            iter_twich_difference_dict[iter_percent] = iter_percent_difference_dict
+
+        time_differences.append(iter_twich_difference_dict)
+
+    return time_differences
+
+
 def calculate_twitch_widths(
     twitch_indices: Dict[int, Dict[UUID, Optional[int]]],
     filtered_data: NDArray[(2, Any), int],
     round_to_int: bool = True,
-) -> List[Dict[int, Dict[UUID, Union[Tuple[Union[float, int], Union[float, int]], Union[float, int]],],]]:
+) -> List[Dict[int, Dict[UUID, Any]]]:
     """Determine twitch width between 10-90% down to the nearby valleys.
 
     Args:
@@ -569,25 +642,14 @@ def calculate_twitch_widths(
     Returns:
         a list of dictionaries where the first key is the percentage of the way down to the nearby valleys, the second key is a UUID representing either the value of the width, or the rising or falling coordinates. The final value is either an int (for value) or a tuple of ints for the x/y coordinates
     """
-    widths: List[
-        Dict[
-            int,
-            Dict[
-                UUID,
-                Union[Tuple[Union[float, int], Union[float, int]], Union[float, int]],
-            ],
-        ]
-    ] = list()
+    widths: List[Dict[int, Dict[UUID, Any]]] = list()
+
     value_series = filtered_data[1, :]
     time_series = filtered_data[0, :]
     for iter_twitch_peak_idx, iter_twitch_indices_info in twitch_indices.items():
-        iter_width_dict: Dict[
-            int,
-            Dict[
-                UUID,
-                Union[Tuple[Union[float, int], Union[float, int]], Union[float, int]],
-            ],
-        ] = dict()
+
+        iter_width_dict: Dict[int, Dict[UUID, Any]] = dict()
+
         peak_value = value_series[iter_twitch_peak_idx]
         prior_valley_value = value_series[iter_twitch_indices_info[PRIOR_VALLEY_INDEX_UUID]]
         subsequent_valley_value = value_series[iter_twitch_indices_info[SUBSEQUENT_VALLEY_INDEX_UUID]]
@@ -629,7 +691,9 @@ def calculate_twitch_widths(
                 value_series[falling_idx - 1],
             )
             width_val = interpolated_falling_timepoint - interpolated_rising_timepoint
-            if round_to_int:
+            if (
+                round_to_int
+            ):  # pragma: no cover  # Tanner (10/28/21): currently no tests that cover this branch but it could be still called in Pulse3D
                 width_val = int(round(width_val, 0))
                 interpolated_falling_timepoint = int(round(interpolated_falling_timepoint, 0))
                 interpolated_rising_timepoint = int(round(interpolated_rising_timepoint, 0))
@@ -647,6 +711,7 @@ def calculate_twitch_widths(
             )
             iter_width_dict[iter_percent] = iter_percent_dict
         widths.append(iter_width_dict)
+
     return widths
 
 
@@ -772,7 +837,9 @@ def calculate_area_under_curve(  # pylint:disable=too-many-locals # Eli (9/1/20)
             rising_coords,
             falling_coords,
         )
-        if round_to_int:
+        if (
+            round_to_int
+        ):  # pragma: no cover  # Tanner (10/28/21): currently no tests that cover this branch but it could be still called in Pulse3D
             auc_total = int(round(auc_total, 0))
         auc_per_twitch.append(auc_total)
 
